Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7327)

Unified Diff: chrome/browser/ui/webui/options/extension_settings_handler.h

Issue 8176001: Warn user in case extension delays network traffic too much. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Merged with ToT Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/options/extension_settings_handler.h
diff --git a/chrome/browser/ui/webui/options/extension_settings_handler.h b/chrome/browser/ui/webui/options/extension_settings_handler.h
index d326a1d0bc43b6b3263615b49c53b0a35efda2bb..f0bfdf0a193553518196515951b5a9f61d535ffc 100644
--- a/chrome/browser/ui/webui/options/extension_settings_handler.h
+++ b/chrome/browser/ui/webui/options/extension_settings_handler.h
@@ -11,6 +11,7 @@
#include "chrome/browser/extensions/extension_install_ui.h"
#include "chrome/browser/extensions/extension_uninstall_dialog.h"
+#include "chrome/browser/extensions/extension_warning_set.h"
#include "chrome/browser/ui/shell_dialogs.h"
#include "chrome/browser/ui/webui/options/options_ui.h"
#include "chrome/browser/ui/webui/chrome_web_ui.h"
@@ -57,11 +58,12 @@ class ExtensionSettingsHandler : public OptionsPageUIHandler,
static void RegisterUserPrefs(PrefService* prefs);
// Extension Detail JSON Struct for page. (static for ease of testing).
// Note: service can be NULL in unit tests.
static base::DictionaryValue* CreateExtensionDetailValue(
ExtensionService* service,
const Extension* extension,
const std::vector<ExtensionPage>& pages,
+ const ExtensionWarningSet* warnings,
bool enabled,
bool terminated);
« no previous file with comments | « chrome/browser/resources/options/extension_settings.css ('k') | chrome/browser/ui/webui/options/extension_settings_handler.cc » ('j') | no next file with comments »
@@ -57,11 +58,12 @@ class ExtensionSettingsHandler : public OptionsPageUIHandler,
static void RegisterUserPrefs(PrefService* prefs);
// Extension Detail JSON Struct for page. (static for ease of testing).
- // Note: service can be NULL in unit tests.
+ // Note: |service| and |warnings| can be NULL in unit tests.
static base::DictionaryValue* CreateExtensionDetailValue(
ExtensionService* service,

Powered by Google App Engine
This is Rietveld 408576698